"""
Tests for biased-stop-words
"""
import random
import unittest
from types import ListType, StringType

from biased_stop_words import BiasedStopWordError, Genre, genres, get_stop_words


class TestGetStopWords(unittest.TestCase):

    def test_get_existing_stop_words(self):
        actual = get_stop_words('gendered')
        self.assertTrue(type(actual) is ListType)
        self.assertTrue(actual)

    def test_get_multiple_existing_stop_words(self):
        actual = get_stop_words('gendered', 'us-names')
        self.assertTrue(type(actual) is ListType)
        self.assertTrue(actual)

    def test_get_no_supplied_genres(self):
        self.assertRaises(BiasedStopWordError, get_stop_words)

    def test_get_non_existing_genre(self):
        self.assertRaises(BiasedStopWordError, get_stop_words, 'non-existant-genre')


class TestGenre(unittest.TestCase):

    def test_existing_genre(self):
        actual = Genre('gendered').get_words()
        self.assertTrue(type(actual) is ListType)
        self.assertTrue(actual)

    def test_not_existing_genre(self):
        self.assertRaises(BiasedStopWordError, Genre, 'non-existant-genre')


class TestGenres(unittest.TestCase):

    def test_existing_genre(self):
        actual = genres()
        self.assertTrue(type(actual) is StringType)
        self.assertTrue(actual)


if __name__ == '__main__':
    unittest.main()



import yaml
import os

CURRENT_DIR = os.path.dirname(os.path.realpath(__file__))
STOP_WORDS_DIR = os.path.join(CURRENT_DIR, 'biased-stop-words')
MAPPING_FILE = os.path.join(STOP_WORDS_DIR, 'mapping.yaml')
MAPPING = yaml.load(open(MAPPING_FILE))


def genres():
    return ', '.join(MAPPING.keys())

def get_stop_words(*args):
    if not args:
        raise BiasedStopWordError('include at least one stop word genre')
    stop_words = []
    for genre_name in args:
        stop_words += Genre(genre_name).get_words()
    return list(set(stop_words))


class BiasedStopWordError(Exception):
    pass


class Genre(object):
    def __init__(self, name):
        if name not in MAPPING.keys():
            raise BiasedStopWordError('included genre not ' + genres())
        self.name = name

    def get_words(self):
        words = []
        genre = MAPPING[self.name]
        for filename in genre['files']:
            words += self.__load_words_from_file(filename, genre.get('limit'))
        return words

    def __load_words_from_file(self, filename, limit):
        genre_filename = os.path.join(STOP_WORDS_DIR, filename)
        with open(genre_filename, 'rb') as genre_file:
            if limit:
                return [line.decode('utf-8').strip() for line in genre_file.readlines()][:limit]
            else:
                return [line.decode('utf-8').strip() for line in genre_file.readlines()]



from setuptools import setup, find_packages

setup(
    name='biased-stop-words',
    version='2017.5.13.1',
    description='Generates biased stop word lists for various genres',
    long_description=open('README.rst').read(),
    url='https://github.com/gregology/python-biased-stop-words',
    author='Greg Clarke',
    author_email='greg@gho.st',
    license='MIT',
    classifiers=[
    'Development Status :: 4 - Beta',
    'Intended Audience :: Developers',
    'Topic :: Software Development :: Build Tools',
    'License :: OSI Approved :: MIT License',
    'Programming Language :: Python'
    ],
    keywords='stop words machine learning ml bias biased natural language processing nlp',
    packages=find_packages(),
    install_requires=['pyyaml'],
    package_data={
        'biased_stop_words': [
            'biased-stop-words/*.txt',
            'biased-stop-words/mapping.yaml'
        ]
    }
)
